.. highlight:: shell

==========
Quickstart
==========


To install Wistia API Helper, run this command in your terminal:

.. code-block:: console

    $ pip install wystia

TODO

There's also an `examples/`_ directory in the project page on GitHub
with sample scripts that can be run as needed.

.. _examples/: https://github.com/rnag/wystia/tree/main/examples
